@@ -33,9 +33,6 @@
 ;; M-x flyspell-prog-mode.
 ;; In that mode only text inside comments is checked.
 ;;
-;; Note: consider setting the variable ispell-parser to `tex' to
-;; avoid TeX command checking; use `(setq ispell-parser 'tex)'.
-;;
 ;; Some user variables control the behavior of flyspell.  They are
 ;; those defined under the `User variables' comment.
 
@@ -993,14 +990,17 @@ Mostly we check word delimiters."
 ;;*---------------------------------------------------------------------*/
 ;;*    flyspell-word-search-backward ...                                */
 ;;*---------------------------------------------------------------------*/
-(defun flyspell-word-search-backward (word bound)
+(defun flyspell-word-search-backward (word bound &optional ignore-case)
   (save-excursion
     (let ((r '())
 	  (inhibit-point-motion-hooks t)
 	  p)
       (while (and (not r) (setq p (search-backward word bound t)))
 	(let ((lw (flyspell-get-word)))
-	  (if (and (consp lw) (string-equal (car lw) word))
+	  (if (and (consp lw)
+		   (if ignore-case
+		       (string-equal (downcase (car lw)) (downcase word))
+		     (string-equal (car lw) word)))
 	      (setq r p)
 	    (goto-char p))))
       r)))
@@ -1069,7 +1069,7 @@ misspelling and skips redundant spell-checking step."
 			      (- end start)
 			      (- (skip-chars-backward " \t\n\f"))))
 			  (p (when (>= bound (point-min))
-			       (flyspell-word-search-backward word bound))))
+			       (flyspell-word-search-backward word bound t))))
 		     (and p (/= p start)))))
 	    ;; yes, this is a doublon
 	    (flyspell-highlight-incorrect-region start end 'doublon)
